Version

Enum Version 

#[non_exhaustive]
pub enum Version { V2_0, V2_1, }
The NodeInfo schema version this document conforms to.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


V2_0

NodeInfo 2.0 — schema.



V2_1

NodeInfo 2.1 — schema.

Implementations

Source

impl Version

pub const fn as_str(self) -> &'static str

Returns the version as the lexical string used on the wire.

pub const fn schema_uri(self) -> &'static str

Returns the full schema URI this version corresponds to, as emitted in the rel field of the /.well-known/nodeinfo discovery document.