#[non_exhaustive]pub struct Usage {
pub users: UserCount,
pub local_posts: Option<u64>,
pub local_comments: Option<u64>,
}Expand description
Aggregate server usage statistics.
Per the NodeInfo schema the users field is required; the other fields
are optional but conventionally reported by large instances.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.users: UserCountPer-user counts (required field; may contain all None values if
the server chooses not to disclose them).
local_posts: Option<u64>Total number of posts authored by local users.
local_comments: Option<u64>Total number of comments authored by local users.
Implementations
Sourceimpl Usage
impl Usage
Sourcepub const fn new(users: UserCount) -> Self
pub const fn new(users: UserCount) -> Self
Constructs a Usage with only the required users field set.
Sourcepub const fn with_local_posts(self, posts: u64) -> Self
pub const fn with_local_posts(self, posts: u64) -> Self
Sets the total number of posts authored by local users.
Sourcepub const fn with_local_comments(self, comments: u64) -> Self
pub const fn with_local_comments(self, comments: u64) -> Self
Sets the total number of comments authored by local users.